(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     92531,       2421]
NotebookOptionsPosition[     86586,       2228]
NotebookOutlinePosition[     87009,       2244]
CellTagsIndexPosition[     86966,       2241]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Posterior-Decodierung"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670321893142056*^9, 
  3.6704006274079857`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Die Bestimmung der Posteriorwahrscheinlichkeit f\[UDoubleDot]r eine \
gegebene Sequenz des Kasinobeispiels motiviert diesen ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs. Die Posteriorwahrscheinlichkeit\nbasiert auf dem ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "- und ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmus, die wir nun in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementieren werden. Die zugeh\[ODoubleDot]rigen Definitionen finden \
sich in den Gleichungen (2.101) bis (2.111).\n\nDer Zustandsraum des HMM, der \
Zustandsraum der Sequenz, die \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten und die \
Emissionswahrscheinlichkeiten entsprechen f\[UDoubleDot]r den ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "- Algorithmus den Definitionen aus dem ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs zum Viterbi-Algorithmus. "
}], "Text",
 CellChangeTimes->{{3.6746265940415154`*^9, 3.674626630756571*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"state", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<0\>\"", ",", "\"\<F\>\"", ",", "\"\<U\>\""}], "}"}]}], 
  ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"observation", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}]}], 
  ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"emission", "[", 
    RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", 
   RowBox[{"Switch", "[", 
    RowBox[{"z1", ",", "\[IndentingNewLine]", "\"\<F\>\"", ",", 
     RowBox[{"N", "[", 
      RowBox[{"1", "/", "6"}], "]"}], ",", "\[IndentingNewLine]", "\"\<U\>\"",
      ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"z2", "\[Equal]", "6"}], ",", "0.5", ",", "0.1"}], "]"}], ",", 
     "\[IndentingNewLine]", "\"\<0\>\"", ",", "0"}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"transition", "[", 
    RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", 
   RowBox[{"Switch", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z1", ",", "z2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<F\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.95", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<F\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.05", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<U\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.90", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<U\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.10", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<0\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.5", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<0\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.5", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<0\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.0", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<U\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.0", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<F\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.0"}], "]"}]}], 
  ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "2", "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"seq0a", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", 
    RowBox[{"{", "50", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.622881080642541*^9, 3.622881089376281*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "2", ",", "3", ",", "3", ",", "6", ",", "3", ",", "2", ",", "6", 
   ",", "6", ",", "1", ",", "1", ",", "5", ",", "4", ",", "5", ",", "1", ",", 
   "2", ",", "2", ",", "6", ",", "2", ",", "6", ",", "5", ",", "5", ",", "1", 
   ",", "1", ",", "5", ",", "5", ",", "2", ",", "3", ",", "4", ",", "4", ",", 
   "1", ",", "2", ",", "1", ",", "5", ",", "3", ",", "3", ",", "2", ",", "6", 
   ",", "5", ",", "4", ",", "1", ",", "6", ",", "6", ",", "3", ",", "3", ",", 
   "2", ",", "3", ",", "6", ",", "3", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713550829086`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"seq0b", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RandomReal", "[", "]"}], "<", "0.5"}], ",", "6", ",", 
      RowBox[{"RandomInteger", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5"}], "}"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", "20", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.622881098875078*^9, 3.622881113149008*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "2", ",", "6", ",", "5", ",", "6", ",", "6", ",", "6", ",", "6", 
   ",", "6", ",", "5", ",", "2", ",", "1", ",", "6", ",", "6", ",", "3", ",", 
   "5", ",", "6", ",", "2", ",", "6", ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713550985084`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"seq0c", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", 
    RowBox[{"{", "50", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.622881109170987*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "6", ",", "5", ",", "5", ",", "6", ",", "3", ",", "5", ",", "4", 
   ",", "6", ",", "3", ",", "1", ",", "4", ",", "3", ",", "3", ",", "4", ",", 
   "3", ",", "4", ",", "3", ",", "4", ",", "6", ",", "2", ",", "5", ",", "3", 
   ",", "3", ",", "3", ",", "4", ",", "2", ",", "6", ",", "5", ",", "1", ",", 
   "4", ",", "3", ",", "1", ",", "1", ",", "2", ",", "1", ",", "5", ",", "3", 
   ",", "3", ",", "1", ",", "5", ",", "1", ",", "3", ",", "1", ",", "3", ",", 
   "6", ",", "3", ",", "2", ",", "3", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713551297083`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"label", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{"\"\<F\>\"", ",", 
        RowBox[{"{", "50", "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{"\"\<U\>\"", ",", 
        RowBox[{"{", "20", "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{"\"\<F\>\"", ",", 
        RowBox[{"{", "50", "}"}]}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"seq", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"seq0a", ",", "seq0b", ",", "seq0c"}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"L", "=", 
  RowBox[{"Length", "[", "seq", "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["120"], "Output",
 CellChangeTimes->{3.677571355176509*^9}]
}, Open  ]],

Cell[TextData[{
 "Als Beispielsequenz nutzen wir den im vorangegangenen Exkurs erstellten \
Datensatz, der aus drei Teilsequenzen nach dem Schema fair \[Dash] unfair \
\[Dash] fair zusammengesetzt ist. Die Viterbi-Variable wird nun durch die ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Variable abgel\[ODoubleDot]st. Die Maximumsabfrage wird durch eine \
Summation ersetzt. Damit ergibt sich der ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Algorithmus als"
}], "Text",
 CellChangeTimes->{{3.6746266678876286`*^9, 3.6746267027446823`*^9}, {
  3.6775640552521086`*^9, 3.677564057889513*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"forward", "[", 
   RowBox[{"z1_", ",", "0", ",", "x_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"z1", "==", "\"\<0\>\""}], ",", "1", ",", "0"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"tmpList", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"forward", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"i", "-", "1"}], ",", "seq"}], "]"}], "*", 
            RowBox[{"transition", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], ";"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"forward", "[", 
         RowBox[{
          RowBox[{"state", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
        RowBox[{
         RowBox[{"emission", "[", 
          RowBox[{
           RowBox[{"state", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{"seq", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"Plus", "@@", "tmpList"}], ")"}]}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Die ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Variable kann nun f\[UDoubleDot]r die Zust\[ADoubleDot]nde 1 (\
\[OpenCurlyQuote]0\[CloseCurlyQuote]), 2 \
(\[OpenCurlyQuote]F\[CloseCurlyQuote]) und 3 (\[OpenCurlyQuote]U\
\[CloseCurlyQuote]) f\[UDoubleDot]r jeden Sequenzindex ",
 StyleBox["i",
  FontSlant->"Italic"],
 " berechnet werden. Einige Beispiele:"
}], "Text",
 CellChangeTimes->{{3.6746267433727446`*^9, 3.6746267711467857`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "0", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.677571355285709*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.08333333333333333`", ",", "0.25`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713553013086`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "2", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.01736111111111111`", ",", "0.02291666666666667`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571355316909*^9}]
}, Open  ]],

Cell[TextData[{
 "Als Terminierung (",
 StyleBox["i = L",
  FontSlant->"Italic"],
 ") hat man"
}], "Text",
 CellChangeTimes->{{3.6746268331918774`*^9, 3.6746268510159054`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmpList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"forward", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "L", ",", "seq"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "7.656593788662696`*^-93", ",", "7.498328096864055`*^-94"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775713553481092`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Gesamtwahrscheinlichkeit f\[UDoubleDot]r die Sequenz ergibt sich durch \
die Summation der ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Variablen zum Sequenzindex ",
 StyleBox["i = L",
  FontSlant->"Italic"],
 ", multipliziert mit der \[CapitalUDoubleDot]bergangswahrscheinlichkeit in \
den Endzustand \[OpenCurlyQuote]0\[CloseCurlyQuote]."
}], "Text",
 CellChangeTimes->{{3.6746268649079285`*^9, 3.6746269067069893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probSeqForward", "=", 
  RowBox[{
   RowBox[{"Plus", "@@", "tmpList"}], "*", "0.5"}]}]], "Input"],

Cell[BoxData["4.203213299174551`*^-93"], "Output",
 CellChangeTimes->{3.6775713553793087`*^9}]
}, Open  ]],

Cell[TextData[{
 "Der \[CapitalUDoubleDot]bergang aus den Zust\[ADoubleDot]nden \
\[OpenCurlyQuote]F\[CloseCurlyQuote] und \[OpenCurlyQuote]U\[CloseCurlyQuote] \
in einen Endzustand wird in der von uns definierten Funktion der \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten nicht \
ber\[UDoubleDot]cksichtigt. Daher setzen wir die entsprechende \
Wahrscheinlichkeit von 0.5 explizit ein. \n\nNeben der ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Variablen ben\[ODoubleDot]tigen wir f\[UDoubleDot]r die \
Posterior-Decodierung die ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Variable. Der ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmus unterscheidet sich vom ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Algorithmus und vom Viterbi-Algorithmus, wie wir gesehen haben, vor allem \
dadurch, dass er am Ende der Sequenz startet. Deshalb ist es \
n\[ODoubleDot]tig, eine auf diese Situation angepasste Funktion der \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten anzugeben, \
w\[ADoubleDot]hrend der Zustandsraum des HMM, der Zustandsraum der Sequenz \
und die Emissionswahrscheinlichkeiten beibehalten werden. Die \
Wahrscheinlichkeit, vom Endzustand \[OpenCurlyQuote]0\[CloseCurlyQuote] in \
den Zustand \[OpenCurlyQuote]F\[CloseCurlyQuote] oder \[OpenCurlyQuote]U\
\[CloseCurlyQuote] \[UDoubleDot]berzugehen, wird wieder jeweils als 0.5 \
definiert."
}], "Text",
 CellChangeTimes->{{3.6746269736770906`*^9, 3.674627034735182*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"transitionII", "[", 
   RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", 
  RowBox[{"Switch", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"z1", ",", "z2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.95", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.05", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.90", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.10", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.5", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.5"}], 
   "]"}]}]], "Input"],

Cell[TextData[{
 "Der ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmus kann nun wie folgt implementiert werden:"
}], "Text",
 CellChangeTimes->{{3.6746270568132153`*^9, 3.6746270663602304`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"backward", "[", 
   RowBox[{"z1_", ",", "L", ",", "x_"}], "]"}], ":=", 
  RowBox[{"transitionII", "[", 
   RowBox[{"z1", ",", "\"\<0\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"tmpList", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"backward", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"i", "+", "1"}], ",", "seq"}], "]"}], "*", 
            RowBox[{"emission", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"seq", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], "*", 
            RowBox[{"transition", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], ";"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"backward", "[", 
         RowBox[{
          RowBox[{"state", "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
        RowBox[{"Plus", "@@", "tmpList"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"L", "-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Man erkennt an der Festlegung des Laufindex der \[ADoubleDot]u\[SZ]eren ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife, dass die Iteration nun r\[UDoubleDot]ckw\[ADoubleDot]rts \
erfolgt. Die Terminierung besch\[ADoubleDot]ftigt sich daher mit der \
Indexposition\n",
 StyleBox["i = 1",
  FontSlant->"Italic"],
 ". Die Werte der ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Variablen an dieser Stelle lassen sich in der \[UDoubleDot]blichen Weise \
abfragen:"
}], "Text",
 CellChangeTimes->{{3.6746270765132456`*^9, 3.6746271073442936`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmpList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"backward", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.4702514372880525`*^-92", ",", "1.9725413113737`*^-92", ",", 
   "1.023771549211921`*^-92"}], "}"}]], "Output",
 CellChangeTimes->{3.677571355488509*^9}]
}, Open  ]],

Cell[TextData[{
 "Summation \[UDoubleDot]ber die (mit den entsprechenden \
\[CapitalUDoubleDot]bergangs- und Emissionswahrscheinlichkeiten versehenen) ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Variablen bei ",
 StyleBox["i = 1",
  FontSlant->"Italic"],
 " ist ein alternativer Weg zur Gesamtwahrscheinlichkeit ",
 StyleBox["P",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") der Sequenz ",
 StyleBox["x",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.674627141119343*^9, 3.6746271556663637`*^9}, 
   3.6746272101074505`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probSeqBackward", "=", 
  RowBox[{"Plus", "@@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"transition", "[", 
       RowBox[{"\"\<0\>\"", ",", 
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "*", 
      RowBox[{"emission", "[", 
       RowBox[{
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"seq", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
      RowBox[{"backward", "[", 
       RowBox[{
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData["4.2032132991745525`*^-93"], "Output",
 CellChangeTimes->{3.677571355519709*^9}]
}, Open  ]],

Cell[TextData[{
 "Die f\[UDoubleDot]r unsere Sequenz durch den ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmus berechnete Gesamtwahrscheinlichkeit ist mit dem durch den ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Algorithmus bestimmten Wert identisch. Diese \
\[CapitalUDoubleDot]bereinstimmung ist eine gute \
Konsistenzpr\[UDoubleDot]fung der Implementierung. Die \
Posteriorwahrscheinlichkeit entlang einer Sequenz kann nun durch Zusammenf\
\[UDoubleDot]gen der oben definierten ",
 StyleBox["forward",
  FontSlant->"Italic"],
 "- und ",
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmen berechnet werden."
}], "Text",
 CellChangeTimes->{{3.6746272145914574`*^9, 3.674627221397467*^9}, 
   3.6746272528225136`*^9, {3.6746290852923183`*^9, 3.674629086147322*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"postDec", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"forward", "[", 
        RowBox[{
         RowBox[{"state", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "*", 
       RowBox[{"backward", "[", 
        RowBox[{
         RowBox[{"state", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}]}], 
      ")"}], "/", "probSeqBackward"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Die Wahrscheinlichkeit f\[UDoubleDot]r einen fairen W\[UDoubleDot]rfel wird \
auf diese Weise entlang der Sequenz protokolliert:\
\>", "Text",
 CellChangeTimes->{{3.6746273105565987`*^9, 3.674627324288619*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"postTable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"postDec", "[", 
      RowBox[{"\"\<F\>\"", ",", "i", ",", "seq"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 "Die folgenden ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Befehle dienen der Visualisierung des Ergebnisses. Abbildung 2.53 zeigt \
die Posteriorwahrscheinlichkeit f\[UDoubleDot]r das Vorliegen eines fairen W\
\[UDoubleDot]rfels entlang der Abfolge von W\[UDoubleDot]rfelereignissen. Die \
grau hinterlegte Fl\[ADoubleDot]che markiert die Teilsequenz, der ein \
unfairer W\[UDoubleDot]rfel zugrunde liegt."
}], "Text",
 CellChangeTimes->{{3.674627363303678*^9, 3.6746273811127057`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"label1", "=", 
   RowBox[{"label", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<F\>\"", "\[Rule]", "0"}], ",", 
      RowBox[{"\"\<U\>\"", "\[Rule]", "1"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plpost", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"postTable", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.574152700125*^9, 3.57415270540625*^9}, {
   3.574152827328125*^9, 3.57415282775*^9}, {3.574152880859375*^9, 
   3.574152952953125*^9}, {3.574153390453125*^9, 3.57415339128125*^9}, 
   3.574154103203125*^9, {3.6775567872496386`*^9, 3.6775567880452394`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9lAlME2YYhosTFJ1VGUwcagApU2HagiLglBekqOWwlKvcCC0qiIAjQ9Rp
yZZsK4cnEAhaZB7zyMbmMUYybFY8hjqxgoAwIyCieFRwzMEU5rLvs0nTPH3/
5//+2yE5U6EeJxAItr75/vf7/+e5j9GsR7JpQrsP/YHbr86cG7C5RzwRUyyX
z5ae6CKehhc1md5zrjFbo6N2NOOqltvbosqs4KLsNeezMOKU9GmPRTexPer8
Jk8ZPsntHVF9VbJ9wjucOyHbrOR47Nk+YmcMbS92uNreTzwPskW51w27nxAv
QMNLw3FT1lNiVwxKS7uM15gX4rN65YZ7BmYx3GomJ5sUzBJMdCnSzlZwf27w
25e//+dUrueOYKsnbY7dzItxQBi2OKGUeQmO3nneMFzPvgfUrzv7tIPc/1I4
jyw//N3BZ8SeeCBL2dn8itkLSeaVC0olJmJvhPfNMCsJYV6G3iMn1wgTmD9G
//kr97eqmZcj6FKS7JP1zCvQaiEPqVEx+8CmaCjAI44Z+KLhUbdFILEGMJRn
F0xz4dwX4/MkBssBGp/GF6fPrTDkfMXj9YNatUmQwuur8YNqrDstbRvPfyWE
+aoEiR2tj2YlLO2Nh08F83r5Y8mtDGX2t48o90dJTuqG+QO831IkdrpknSm8
T7kU9w7ekB2LIxYEYKN/la2LM7XXBCA5zfTXofSHlK9Cfo+uxaQj1qyCrl/k
XdbC/a+G1eYZ6fYXeylfjRHfPeGzsh5QvgaJbVH1sS85XwNTeoXUW8z1ZZCW
Dp8czaPzq5HB9Nr1d8mkW5QHYlrLyJaYquuUB6Kx5gOvtvifKA+Ci+4XB8vE
Y5QHIVeu+mPpRzrKg+G3ambyXOtqyoMxuq8x2GlLDeUhmNPe4XBEa6A8BM17
jiaIei9TvhY3d1uUzzNeonwtvszsX+TUdYFyObSn1VZ2JcSQo/T9cfIiCbeX
w6J6be22fmK9HLs0nRe/8fiV/FA8jgwZrLNqID8UJ1SOwnev6MkPhVbU2tt2
hManD8WHhe1GL5sm8hVYsqwv06nASL4CO7aLnMpCO8lXQN31Qj9QTOurVyCn
Tny5V87vSRj22vtXNTbQ/iAMOwbT/3a35v0OQ/9DF/9/ptL50oe9qbDNetJ0
YkE48ha2PbPpekx+OOpluTphNp/ncCyMqTe6hdB514ejzVyyseISn/8I5O29
HdU4nu4LIiCeq9HWzuH7FIFiia170WxifQTsPJdW3hXw/YrEQOeF5oJ66g+R
8OxpNJ/vw/ctEl6b/5xRF0Hj0UfCvEzY5+jF9aOwW33o4Xtn2I/C/sSnY5XP
2I9C4I8ZiQ1cTx+FdUNe4hcm9pX4OlNk73WefSVu5A7ucn9bX4mcBXej7yRx
fSWKXVurbgaxHw0PhbOtcxP70Vhstj7FcybPPxoTxX6pt325fjT2BxVOUSp5
/jG4YGcUvH2fEIPfnu8UeaezH4NmVdL30s3sx8BY7NbXyyyIxZDCdV1YBvux
mH/j0cuxDezH4nPFcLkqif1YZJimi3Pl7MfhVJpHa5k7+3EYn5yZemCM5x+H
47q5NcJq3v84VJ/NGh0b5vc8HgG1TalTr9F7h3gUVpYf7Sjg8xOPigMpHfFN
vH7xaDGpMy7/wH4C4is8nQJFT33+Bas9Sm8=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 120.}, {0, 0.9822873607231151}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775713558629103`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die diskrete Natur der hier aufgetragenen Posteriorwahrscheinlichkeit l\
\[ADoubleDot]sst sich durch das Hinzuf\[UDoubleDot]gen von Punkten an den \
(ganzzahligen) Sequenzpositionen \[UDoubleDot]ber die Option ",
 StyleBox["Mesh \[Rule] Full",
  FontWeight->"Bold"],
 " hervorheben. "
}], "Text",
 CellChangeTimes->{{3.677557079891354*^9, 3.6775571265822363`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"postTable", ",", 
   RowBox[{"Mesh", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6775570482700987`*^9, 3.6775570546193094`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztlflTE0YUx4MVFK1RKVQs6gAmVIVqAoIEq3xBghoOQ7jCEUBIUEEuy5Si
VsPYmbbh8AQGBg1Sj3pMS+tRykwx0+BR1IoRBIQ6AiKKSjhKLVShdtznn9Cf
kplM5pPvfvftvn27zyExQ6aaxOFwBl5///t98xnwNph1C7dOafNmf+Duy3MX
Bm0eMJ6KGZar5otPdTKeheHqDK8FN4it0V4znnZdQ+NtUWmWf1nyivR5GOMl
fNpt0cXYHrW+02eMnqbxjqi6Ltwx5R3SecgyKz4Zc76XsRNGdhQ5XG/rY7wI
kmU5N/V7nzFegvoX+pPGzOeMXTAkLuk03CBeis/r5Jsf6IkFcK2enmiUEQsx
1blQM19G87nC90DewZ+TKZ4bgqyetTp2ES/HIW7o8rgSYnccvzdQP1pHfg+o
XnX0aoZo/hVwGlt19LvD/Yw98UiStKvpJbEICeYVS0qERsZeCOudY1YcTLwS
PcdOr+fGEX+MvovXHn6mIl6FwCsJkk82Ea9Gi4U0uFpJ7A2bwhF/j1hi4Iv6
J10WAYzVgL4sK3+WM+k+mJwr1FsOsvWpfXD2wmp99le0Xl+olFs5SZRftS+U
E10pKdtp/2vAzVPGCe1YftRrYGlvOHomiPLlB/c7afKsb58w3Q/F2cmbFw/S
eYsR3+Gcea7gIdPFeHD4luRELGOOP7b4Vdo6O7Hxan8kphj/OpL6mOlrkdet
bTZqGavXQtvH9yptpvnXwSp9Tqr95R6mr8OYz76weZmPmL4e8a2RdTEvSF8P
Y2q52EtA8SUQl4yeHs9l9auWwPjK5XfhtDtMD8Cs5rFt0ZU3mR6AhuoPRK2K
n5geCGftLw6W8SeYHogcqfKPFR9pmR4E37VzExdaVzE9COMHGoJ426qZHowF
be0OxzR6pgejad/xOH7PVaZvwO29FmWLDFeYvgFfZvQt43VeYroUmrMqK7ti
xpCi5P1J0kIhjZfCompDzfY+xjopdqs7Ln/j8Svzh+BpRPBQrVU984fglNKR
++41HfOHQMNv6Wk9xtanC8GHBW0GkU0j88vgvrI3g5dvYH4Zdu7g80pDOphf
BlXnsG6wiOVXJ0N2reBqj5Tek1Dst/erbKhn54NQ7BxK/dvNms47FH2Pnf3+
mcnqSxf6OsJ262mzGXPCkLu0td+m8ynzh6FOkqPlZlE9h2FpdJ3BNZjVuy4M
rebCLeVXqP7Dkbv/bmTDZHZfEA7BQrWmZgHdp3AUCW3dCucz1oXDznNFxX0O
3a8IDHZcasqvY/MhAp7dDeaLvem+RUCU/uec2nC2Hl0EzEu5vY4iih+Jvaoj
j987R/5IHIx/PlHRT/5IBPyYFl9P8XSR2DgiEgwbyS/H1xl8e9FF8stxK2do
t9vb+HJkL7kfdS+B4stR5NJSeTuQ/FHwkDnZOjWSPwrLzTYlec6l/UdhqsA3
+a4PxY/CwcCCGXI57T8al+wMnLfvE6Lx28Auvlcq+aPRpEz4XpxO/mgYilx7
e4g5MRiRuWwMTSN/DBbfevJiYjP5Y7BHNlqmTCB/DNKMswU5UvLH4kyKR0up
G/ljMTkxI/nQBO0/Fie1C6u5VXT+sag6nzk+MUrvuQL+NY3JM2+w9w4KFFSU
HW/Pp/pRoPxQUruikfKnQLNRlXb1B/LHQVHuyQvgE5v6r6n/mvqvqf+a+u8b
v6n/mvrv/9N//wWJlJMw
    "], {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], 
       LineBox[{121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 
        133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 
        147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 
        161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
        175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
        189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 
        203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 
        217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 
        231, 232, 233, 234, 235, 236, 237, 238, 239, 240}]}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[6], 
       AbsoluteThickness[1.6], 
       PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
        18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
        35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
        52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
        69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
        86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102,
         103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
         117, 118, 119, 120}]}, {}, {}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 120.}, {0, 0.9822873607231151}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775713559409103`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"coord1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Position", "[", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"label1", "-", 
        RowBox[{"RotateLeft", "[", 
         RowBox[{"label1", ",", "1"}], "]"}]}], "]"}], ",", "1"}], "]"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rectangleList", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "}"}]}], "]"}]}], 
       "}"}], "&"}], ",", 
     RowBox[{"Partition", "[", 
      RowBox[{"coord1", ",", "2"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plrectangle", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", "rectangleList", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6228813075710573`*^9, 3.622881307786165*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plpost", ",", "plrectangle", ",", "plpost", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "0.3"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.574154324703125*^9, {3.5741543643125*^9, 3.574154367734375*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9lAlME2YYhosTFJ1VGUwcagApU2HagiLglBekqOWwlKvcCC0qiIAjQ9Rp
yZZsK4cnEAhaZB7zyMbmMUYybFY8hjqxgoAwIyCieFRwzMEU5rLvs0nTPH3/
5//+2yE5U6EeJxAItr75/vf7/+e5j9GsR7JpQrsP/YHbr86cG7C5RzwRUyyX
z5ae6CKehhc1md5zrjFbo6N2NOOqltvbosqs4KLsNeezMOKU9GmPRTexPer8
Jk8ZPsntHVF9VbJ9wjucOyHbrOR47Nk+YmcMbS92uNreTzwPskW51w27nxAv
QMNLw3FT1lNiVwxKS7uM15gX4rN65YZ7BmYx3GomJ5sUzBJMdCnSzlZwf27w
25e//+dUrueOYKsnbY7dzItxQBi2OKGUeQmO3nneMFzPvgfUrzv7tIPc/1I4
jyw//N3BZ8SeeCBL2dn8itkLSeaVC0olJmJvhPfNMCsJYV6G3iMn1wgTmD9G
//kr97eqmZcj6FKS7JP1zCvQaiEPqVEx+8CmaCjAI44Z+KLhUbdFILEGMJRn
F0xz4dwX4/MkBssBGp/GF6fPrTDkfMXj9YNatUmQwuur8YNqrDstbRvPfyWE
+aoEiR2tj2YlLO2Nh08F83r5Y8mtDGX2t48o90dJTuqG+QO831IkdrpknSm8
T7kU9w7ekB2LIxYEYKN/la2LM7XXBCA5zfTXofSHlK9Cfo+uxaQj1qyCrl/k
XdbC/a+G1eYZ6fYXeylfjRHfPeGzsh5QvgaJbVH1sS85XwNTeoXUW8z1ZZCW
Dp8czaPzq5HB9Nr1d8mkW5QHYlrLyJaYquuUB6Kx5gOvtvifKA+Ci+4XB8vE
Y5QHIVeu+mPpRzrKg+G3ambyXOtqyoMxuq8x2GlLDeUhmNPe4XBEa6A8BM17
jiaIei9TvhY3d1uUzzNeonwtvszsX+TUdYFyObSn1VZ2JcSQo/T9cfIiCbeX
w6J6be22fmK9HLs0nRe/8fiV/FA8jgwZrLNqID8UJ1SOwnev6MkPhVbU2tt2
hManD8WHhe1GL5sm8hVYsqwv06nASL4CO7aLnMpCO8lXQN31Qj9QTOurVyCn
Tny5V87vSRj22vtXNTbQ/iAMOwbT/3a35v0OQ/9DF/9/ptL50oe9qbDNetJ0
YkE48ha2PbPpekx+OOpluTphNp/ncCyMqTe6hdB514ejzVyyseISn/8I5O29
HdU4nu4LIiCeq9HWzuH7FIFiia170WxifQTsPJdW3hXw/YrEQOeF5oJ66g+R
8OxpNJ/vw/ctEl6b/5xRF0Hj0UfCvEzY5+jF9aOwW33o4Xtn2I/C/sSnY5XP
2I9C4I8ZiQ1cTx+FdUNe4hcm9pX4OlNk73WefSVu5A7ucn9bX4mcBXej7yRx
fSWKXVurbgaxHw0PhbOtcxP70Vhstj7FcybPPxoTxX6pt325fjT2BxVOUSp5
/jG4YGcUvH2fEIPfnu8UeaezH4NmVdL30s3sx8BY7NbXyyyIxZDCdV1YBvux
mH/j0cuxDezH4nPFcLkqif1YZJimi3Pl7MfhVJpHa5k7+3EYn5yZemCM5x+H
47q5NcJq3v84VJ/NGh0b5vc8HgG1TalTr9F7h3gUVpYf7Sjg8xOPigMpHfFN
vH7xaDGpMy7/wH4C4is8nQJFT33+Bas9Sm8=
       "]]}}, {}}, 
   {GrayLevel[0.9], RectangleBox[{50, 0}, {70, 1}]}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9lAlME2YYhosTFJ1VGUwcagApU2HagiLglBekqOWwlKvcCC0qiIAjQ9Rp
yZZsK4cnEAhaZB7zyMbmMUYybFY8hjqxgoAwIyCieFRwzMEU5rLvs0nTPH3/
5//+2yE5U6EeJxAItr75/vf7/+e5j9GsR7JpQrsP/YHbr86cG7C5RzwRUyyX
z5ae6CKehhc1md5zrjFbo6N2NOOqltvbosqs4KLsNeezMOKU9GmPRTexPer8
Jk8ZPsntHVF9VbJ9wjucOyHbrOR47Nk+YmcMbS92uNreTzwPskW51w27nxAv
QMNLw3FT1lNiVwxKS7uM15gX4rN65YZ7BmYx3GomJ5sUzBJMdCnSzlZwf27w
25e//+dUrueOYKsnbY7dzItxQBi2OKGUeQmO3nneMFzPvgfUrzv7tIPc/1I4
jyw//N3BZ8SeeCBL2dn8itkLSeaVC0olJmJvhPfNMCsJYV6G3iMn1wgTmD9G
//kr97eqmZcj6FKS7JP1zCvQaiEPqVEx+8CmaCjAI44Z+KLhUbdFILEGMJRn
F0xz4dwX4/MkBssBGp/GF6fPrTDkfMXj9YNatUmQwuur8YNqrDstbRvPfyWE
+aoEiR2tj2YlLO2Nh08F83r5Y8mtDGX2t48o90dJTuqG+QO831IkdrpknSm8
T7kU9w7ekB2LIxYEYKN/la2LM7XXBCA5zfTXofSHlK9Cfo+uxaQj1qyCrl/k
XdbC/a+G1eYZ6fYXeylfjRHfPeGzsh5QvgaJbVH1sS85XwNTeoXUW8z1ZZCW
Dp8czaPzq5HB9Nr1d8mkW5QHYlrLyJaYquuUB6Kx5gOvtvifKA+Ci+4XB8vE
Y5QHIVeu+mPpRzrKg+G3ambyXOtqyoMxuq8x2GlLDeUhmNPe4XBEa6A8BM17
jiaIei9TvhY3d1uUzzNeonwtvszsX+TUdYFyObSn1VZ2JcSQo/T9cfIiCbeX
w6J6be22fmK9HLs0nRe/8fiV/FA8jgwZrLNqID8UJ1SOwnev6MkPhVbU2tt2
hManD8WHhe1GL5sm8hVYsqwv06nASL4CO7aLnMpCO8lXQN31Qj9QTOurVyCn
Tny5V87vSRj22vtXNTbQ/iAMOwbT/3a35v0OQ/9DF/9/ptL50oe9qbDNetJ0
YkE48ha2PbPpekx+OOpluTphNp/ncCyMqTe6hdB514ejzVyyseISn/8I5O29
HdU4nu4LIiCeq9HWzuH7FIFiia170WxifQTsPJdW3hXw/YrEQOeF5oJ66g+R
8OxpNJ/vw/ctEl6b/5xRF0Hj0UfCvEzY5+jF9aOwW33o4Xtn2I/C/sSnY5XP
2I9C4I8ZiQ1cTx+FdUNe4hcm9pX4OlNk73WefSVu5A7ucn9bX4mcBXej7yRx
fSWKXVurbgaxHw0PhbOtcxP70Vhstj7FcybPPxoTxX6pt325fjT2BxVOUSp5
/jG4YGcUvH2fEIPfnu8UeaezH4NmVdL30s3sx8BY7NbXyyyIxZDCdV1YBvux
mH/j0cuxDezH4nPFcLkqif1YZJimi3Pl7MfhVJpHa5k7+3EYn5yZemCM5x+H
47q5NcJq3v84VJ/NGh0b5vc8HgG1TalTr9F7h3gUVpYf7Sjg8xOPigMpHfFN
vH7xaDGpMy7/wH4C4is8nQJFT33+Bas9Sm8=
       "]]}}, {}}},
  AspectRatio->0.3,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 120.}, {0, 0.9822873607231151}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775713562841105`*^9}]
}, Open  ]],

Cell[TextData[{
 "Abbildung 2.53 ist (bis auf die Achsenbeschriftung und Formatierung) das \
Ergebnis dieses letzten ",
 StyleBox["Show",
  FontWeight->"Bold"],
 "-Befehls. Man sieht deutlich, wie die Posteriorwahrscheinlichkeit des \
fairen W\[UDoubleDot]rfels in der \[OpenCurlyQuote]U\[CloseCurlyQuote]-Region \
absinkt.\n\nUm fortgeschrittenere, weniger schematische Tests dieser \
Posterior-Decodierung durchf\[UDoubleDot]hren zu k\[ODoubleDot]nnen, werden \
wir nun ein Programm entwerfen und testen, das pr\[ADoubleDot]zise nach dem \
Modell des Kasinobeispiels Zahlen zwischen 1 und 6 emittiert."
}], "Text",
 CellChangeTimes->{{3.674627425404771*^9, 3.674627488050866*^9}}],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "30", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makeState", "[", "state_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "x", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"state", ",", "\[IndentingNewLine]", "\"\<F\>\"", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", "<=", "0.95"}], ",", "\"\<F\>\"", ",", "\"\<U\>\""}], 
        "]"}], ",", "\[IndentingNewLine]", "\"\<U\>\"", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", "<=", "0.9"}], ",", "\"\<U\>\"", ",", "\"\<F\>\""}], 
        "]"}], ",", "\[IndentingNewLine]", "\"\<0\>\"", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", "<=", "0.5"}], ",", "\"\<F\>\"", ",", "\"\<U\>\""}], 
        "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.622881194100119*^9, 3.6228811962439213`*^9}, {
  3.6228814889757843`*^9, 3.6228814890140743`*^9}, {3.6228815990502253`*^9, 
  3.622881599089398*^9}}],

Cell["\<\
Diese Routine gibt ein Symbol unter Verwendung des (als Argument \
eingetragenen) vorangegangenen Symbols aus:\
\>", "Text",
 CellChangeTimes->{{3.6746275011668854`*^9, 3.6746275137019043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"start", "=", 
  RowBox[{"makeState", "[", "\"\<0\>\"", "]"}]}]], "Input"],

Cell[BoxData["\<\"F\"\>"], "Output",
 CellChangeTimes->{3.6775713563309107`*^9}]
}, Open  ]],

Cell[TextData[{
 "Mit dem Befehl ",
 StyleBox["NestList",
  FontWeight->"Bold"],
 " kann damit nun eine l\[ADoubleDot]ngere Sequenz erzeugt werden:"
}], "Text",
 CellChangeTimes->{{3.674627522459918*^9, 3.674627532147934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stateSeq", "=", 
  RowBox[{"NestList", "[", 
   RowBox[{"makeState", ",", "start", ",", "299"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", 
   ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"U\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", 
   ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>", ",", "\<\"F\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571356362111*^9}]
}, Open  ]],

Cell[TextData[{
 "Dies liefert zugleich die Referenzsequenz f\[UDoubleDot]r den sp\
\[ADoubleDot]teren Vergleich mit der Posteriorwahrscheinlichkeit. Nun kann \
mithilfe der Emissionswahrscheinlichkeiten diese interne Sequenz in eine m\
\[ODoubleDot]gliche, mit den Modellparametern konsistente beobachtete Sequenz \
\[UDoubleDot]berf\[UDoubleDot]hrt werden. Dies geschieht mit einer neuen \
Routine ",
 StyleBox["makeObservation",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.6746275457839556`*^9, 3.6746275502869625`*^9}, {
  3.674627581359008*^9, 3.6746275904960213`*^9}}],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "3", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makeObservation", "[", "state_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "x", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"state", ",", "\[IndentingNewLine]", "\"\<F\>\"", ",", 
       RowBox[{"RandomInteger", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
       "\"\<U\>\"", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", "\[LessEqual]", "0.5"}], ",", "6", ",", 
         RowBox[{"RandomInteger", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "5"}], "}"}], "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.622881220686839*^9, 3.6228812438535137`*^9}, 
   3.622881499591125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"seq", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"makeObservation", "[", 
     RowBox[{"stateSeq", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "stateSeq", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "6", ",", "4", ",", "1", ",", "3", ",", "4", 
   ",", "1", ",", "4", ",", "1", ",", "5", ",", "4", ",", "5", ",", "6", ",", 
   "6", ",", "6", ",", "5", ",", "4", ",", "2", ",", "3", ",", "4", ",", "1", 
   ",", "3", ",", "6", ",", "4", ",", "3", ",", "6", ",", "6", ",", "6", ",", 
   "6", ",", "6", ",", "6", ",", "6", ",", "2", ",", "1", ",", "6", ",", "1", 
   ",", "5", ",", "2", ",", "4", ",", "4", ",", "6", ",", "1", ",", "2", ",", 
   "4", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", ",", "3", ",", "3", 
   ",", "6", ",", "5", ",", "2", ",", "2", ",", "1", ",", "5", ",", "5", ",", 
   "5", ",", "3", ",", "3", ",", "5", ",", "2", ",", "6", ",", "4", ",", "2", 
   ",", "6", ",", "2", ",", "2", ",", "1", ",", "1", ",", "5", ",", "4", ",", 
   "5", ",", "5", ",", "6", ",", "6", ",", "2", ",", "4", ",", "2", ",", "1", 
   ",", "4", ",", "4", ",", "1", ",", "5", ",", "1", ",", "3", ",", "4", ",", 
   "2", ",", "4", ",", "2", ",", "4", ",", "6", ",", "4", ",", "3", ",", "2", 
   ",", "2", ",", "2", ",", "4", ",", "3", ",", "4", ",", "4", ",", "3", ",", 
   "4", ",", "6", ",", "6", ",", "3", ",", "4", ",", "4", ",", "4", ",", "3", 
   ",", "2", ",", "6", ",", "2", ",", "2", ",", "5", ",", "3", ",", "6", ",", 
   "2", ",", "3", ",", "6", ",", "6", ",", "3", ",", "6", ",", "6", ",", "6", 
   ",", "6", ",", "6", ",", "4", ",", "1", ",", "5", ",", "6", ",", "2", ",", 
   "6", ",", "1", ",", "6", ",", "6", ",", "5", ",", "3", ",", "2", ",", "6", 
   ",", "6", ",", "1", ",", "6", ",", "6", ",", "6", ",", "6", ",", "2", ",", 
   "6", ",", "6", ",", "6", ",", "3", ",", "4", ",", "6", ",", "5", ",", "3", 
   ",", "6", ",", "1", ",", "3", ",", "1", ",", "3", ",", "4", ",", "1", ",", 
   "2", ",", "2", ",", "2", ",", "2", ",", "6", ",", "6", ",", "6", ",", "6", 
   ",", "6", ",", "4", ",", "6", ",", "2", ",", "4", ",", "3", ",", "6", ",", 
   "3", ",", "4", ",", "1", ",", "5", ",", "4", ",", "3", ",", "3", ",", "4", 
   ",", "1", ",", "1", ",", "2", ",", "4", ",", "4", ",", "3", ",", "4", ",", 
   "6", ",", "1", ",", "6", ",", "4", ",", "4", ",", "3", ",", "1", ",", "6", 
   ",", "2", ",", "6", ",", "5", ",", "6", ",", "6", ",", "6", ",", "5", ",", 
   "6", ",", "6", ",", "6", ",", "6", ",", "2", ",", "6", ",", "5", ",", "6", 
   ",", "2", ",", "6", ",", "5", ",", "1", ",", "5", ",", "5", ",", "5", ",", 
   "2", ",", "5", ",", "2", ",", "2", ",", "6", ",", "3", ",", "6", ",", "5", 
   ",", "1", ",", "6", ",", "6", ",", "6", ",", "6", ",", "6", ",", "6", ",", 
   "6", ",", "6", ",", "5", ",", "6", ",", "4", ",", "6", ",", "6", ",", "5", 
   ",", "5", ",", "4", ",", "5", ",", "2", ",", "5", ",", "3", ",", "6", ",", 
   "6", ",", "6", ",", "1", ",", "1", ",", "3", ",", "2", ",", "2", ",", "4", 
   ",", "2", ",", "6", ",", "3", ",", "6", ",", "6", ",", "3", ",", "1", ",", 
   "2", ",", "6", ",", "3", ",", "4", ",", "5", ",", "6", ",", "5", ",", "4", 
   ",", "6", ",", "6", ",", "6", ",", "6", ",", "2", ",", "4", ",", "3", ",", 
   "6", ",", "5", ",", "1", ",", "3", ",", "6", ",", "4", ",", "2", ",", "1", 
   ",", "6", ",", "5", ",", "3", ",", "3", ",", "4", ",", "5", ",", "5"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571356424511*^9}]
}, Open  ]],

Cell[TextData[{
 "Abbildung 2.54 zeigt die Posteriorwahrscheinlichkeit ",
 StyleBox["P(F | x)",
  FontSlant->"Italic"],
 " f\[UDoubleDot]r diese Sequenz ",
 StyleBox["x",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.6746276139960566`*^9, 3.674627648614109*^9}, {
   3.674629062162259*^9, 3.67462906272326*^9}, 3.674629110338378*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["forward",
  FontSlant->"Italic"],
 "-Algorithmus"
}], "Subsection",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"L", "=", 
  RowBox[{"Length", "[", "seq", "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["300"], "Output",
 CellChangeTimes->{3.677571356455711*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"forward", "[", 
   RowBox[{"z1_", ",", "0", ",", "x_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"z1", "==", "\"\<0\>\""}], ",", "1", ",", "0"}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"tmpList", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"forward", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"i", "-", "1"}], ",", "seq"}], "]"}], "*", 
            RowBox[{"transition", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], ";"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"forward", "[", 
         RowBox[{
          RowBox[{"state", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
        RowBox[{
         RowBox[{"emission", "[", 
          RowBox[{
           RowBox[{"state", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{"seq", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"Plus", "@@", "tmpList"}], ")"}]}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "0", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.677571356564911*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.08333333333333333`", ",", "0.05`"}], "}"}]], "Output",
 CellChangeTimes->{3.677571356580511*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"forward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "2", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.014027777777777778`", ",", "0.004916666666666667`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.677571356580511*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmpList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"forward", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "L", ",", "seq"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "3.782618370410996`*^-221", ",", "3.362435348212215`*^-222"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775713565961113`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probSeqForward", "=", 
  RowBox[{
   RowBox[{"Plus", "@@", "tmpList"}], "*", "0.5"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["2.059430952616109`*^-221"], "Output",
 CellChangeTimes->{3.6775713566117115`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["backward",
  FontSlant->"Italic"],
 "-Algorithmus"
}], "Subsection",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"transitionII", "[", 
   RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", 
  RowBox[{"Switch", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"z1", ",", "z2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.95", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.05", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.90", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.10", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<U\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<F\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.0", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<U\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.5", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<F\>\"", ",", "\"\<0\>\""}], "}"}], ",", "0.5"}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"backward", "[", 
   RowBox[{"z1_", ",", "L", ",", "x_"}], "]"}], ":=", 
  RowBox[{"transitionII", "[", 
   RowBox[{"z1", ",", "\"\<0\>\""}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"tmpList", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"backward", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"i", "+", "1"}], ",", "seq"}], "]"}], "*", 
            RowBox[{"emission", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"seq", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], "*", 
            RowBox[{"transition", "[", 
             RowBox[{
              RowBox[{"state", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", 
              RowBox[{"state", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], ";"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"backward", "[", 
         RowBox[{
          RowBox[{"state", "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
        RowBox[{"Plus", "@@", "tmpList"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"L", "-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"backward", "[", 
    RowBox[{
     RowBox[{"state", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", "L", ",", "seq"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.5`", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713567521114`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmpList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"backward", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.3615506664207327`*^-220", ",", "1.989056545419643`*^-220", ",", 
   "8.03767662866146`*^-221"}], "}"}]], "Output",
 CellChangeTimes->{3.6775713567677116`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probSeqBackward", "=", 
  RowBox[{"Plus", "@@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"transition", "[", 
       RowBox[{"\"\<0\>\"", ",", 
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "*", 
      RowBox[{"emission", "[", 
       RowBox[{
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"seq", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
      RowBox[{"backward", "[", 
       RowBox[{
        RowBox[{"state", "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", "1", ",", "seq"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["2.059430952616109`*^-221"], "Output",
 CellChangeTimes->{3.677571356783312*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Posterior-Decodierung", "Subsection",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"postDec", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"forward", "[", 
        RowBox[{
         RowBox[{"state", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], "*", 
       RowBox[{"backward", "[", 
        RowBox[{
         RowBox[{"state", "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}]}], 
      ")"}], "/", "probSeqBackward"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "state", "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"postTable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"postDec", "[", 
      RowBox[{"\"\<F\>\"", ",", "i", ",", "seq"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisierung des Resultats", "Subsection",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plpost", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"postTable", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.56871405725*^9, 3.5687140615*^9}, {3.5741539860625*^9, 
  3.574154011171875*^9}, {3.6228817562414913`*^9, 3.622881756456552*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3lczOsXx8eSKEv2riVjvaESkax92oS0K62ammpaptkkcsmQLC0UQm40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      "]]}}, {}},
  AspectRatio->0.3,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 300.}, {0, 0.9809101703301996}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775713569081116`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"label1", "=", 
   RowBox[{"stateSeq", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<F\>\"", "\[Rule]", "0"}], ",", 
      RowBox[{"\"\<U\>\"", "\[Rule]", "1"}]}], "}"}]}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord1", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Position", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"label1", "-", 
       RowBox[{"RotateLeft", "[", 
        RowBox[{"label1", ",", "1"}], "]"}]}], "]"}], ",", "1"}], "]"}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "13", ",", "32", ",", "36", ",", "119", ",", "134", ",", "136", 
   ",", "157", ",", "170", ",", "173", ",", "176", ",", "177", ",", "195", 
   ",", "214", ",", "234", ",", "256", ",", "275", ",", "283"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571356939312*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rectangleList", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "}"}]}], "]"}]}], 
       "}"}], "&"}], ",", 
     RowBox[{"Partition", "[", 
      RowBox[{"coord1", ",", "2"}], "]"}]}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"plrectangle", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", "rectangleList", "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6228812973948317`*^9, 3.62288129765688*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plpost", ",", "plrectangle", ",", "plpost"}], "]"}]], "Input",
 CellChangeTimes->{{3.568714096734375*^9, 3.5687140969375*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3lczOsXx8eSKEv2riVjvaESkax92oS0K62ammpaptkkcsmQLC0UQm40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       "]]}}, {}}, {
    {GrayLevel[0.9], RectangleBox[{11, 0}, {13, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{32, 0}, {36, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{119, 0}, {134, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{136, 0}, {157, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{170, 0}, {173, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{176, 0}]}, 
    {GrayLevel[0.9], RectangleBox[{195, 0}, {214, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{234, 0}, {256, 1}]}, 
    {GrayLevel[0.9], RectangleBox[{275, 0}, {283, 1}]}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3lczOsXx8eSKEv2riVjvaESkax92oS0K62ammpaptkkcsmQLC0UQm40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       "]]}}, {}}},
  AspectRatio->0.3,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 300.}, {0, 0.9809101703301996}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677571357017312*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{791, Automatic}, {226, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 297, 9, 94, "Subtitle"],
Cell[1753, 71, 1008, 26, 258, "Text"],
Cell[2764, 99, 221, 7, 47, "Input"],
Cell[2988, 108, 233, 7, 47, "Input"],
Cell[3224, 117, 579, 15, 108, "Input"],
Cell[3806, 134, 1384, 37, 228, "Input"],
Cell[5193, 173, 127, 3, 47, "Input"],
Cell[CellGroupData[{
Cell[5345, 180, 360, 10, 47, "Input"],
Cell[5708, 192, 624, 10, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6369, 207, 499, 14, 88, "Input"],
Cell[6871, 223, 308, 6, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7216, 234, 336, 10, 47, "Input"],
Cell[7555, 246, 624, 10, 72, "Output"]
}, Open  ]],
Cell[8194, 259, 537, 16, 88, "Input"],
Cell[8734, 277, 212, 6, 47, "Input"],
Cell[CellGroupData[{
Cell[8971, 287, 148, 4, 47, "Input"],
Cell[9122, 293, 72, 1, 31, "Output"]
}, Open  ]],
Cell[9209, 297, 603, 13, 125, "Text"],
Cell[9815, 312, 219, 6, 31, "Input"],
Cell[10037, 320, 1667, 47, 232, "Input"],
Cell[11707, 369, 464, 12, 68, "Text"],
Cell[CellGroupData[{
Cell[12196, 385, 384, 11, 72, "Input"],
Cell[12583, 398, 125, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12745, 406, 384, 11, 72, "Input"],
Cell[13132, 419, 152, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13321, 427, 384, 11, 72, "Input"],
Cell[13708, 440, 168, 4, 31, "Output"]
}, Open  ]],
Cell[13891, 447, 176, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[14092, 457, 351, 10, 52, "Input"],
Cell[14446, 469, 179, 5, 33, "Output"]
}, Open  ]],
Cell[14640, 477, 450, 11, 87, "Text"],
Cell[CellGroupData[{
Cell[15115, 492, 121, 3, 31, "Input"],
Cell[15239, 497, 94, 1, 31, "Output"]
}, Open  ]],
Cell[15348, 501, 1473, 30, 334, "Text"],
Cell[16824, 533, 1273, 34, 212, "Input"],
Cell[18100, 569, 209, 6, 49, "Text"],
Cell[18312, 577, 194, 5, 31, "Input"],
Cell[18509, 584, 1730, 48, 232, "Input"],
Cell[20242, 634, 573, 15, 106, "Text"],
Cell[CellGroupData[{
Cell[20840, 653, 352, 10, 52, "Input"],
Cell[21195, 665, 197, 5, 33, "Output"]
}, Open  ]],
Cell[21407, 673, 577, 20, 87, "Text"],
Cell[CellGroupData[{
Cell[22009, 697, 782, 22, 132, "Input"],
Cell[22794, 721, 93, 1, 31, "Output"]
}, Open  ]],
Cell[22902, 725, 799, 20, 163, "Text"],
Cell[23704, 747, 881, 25, 152, "Input"],
Cell[24588, 774, 220, 4, 49, "Text"],
Cell[24811, 780, 280, 8, 31, "Input"],
Cell[25094, 790, 515, 10, 125, "Text"],
Cell[25612, 802, 234, 7, 31, "Input"],
Cell[CellGroupData[{
Cell[25871, 813, 487, 9, 52, "Input"],
Cell[26361, 824, 3048, 62, 233, "Output"]
}, Open  ]],
Cell[29424, 889, 420, 9, 103, "Text"],
Cell[CellGroupData[{
Cell[29869, 902, 331, 7, 68, "Input"],
Cell[30203, 911, 4487, 82, 233, "Output"]
}, Open  ]],
Cell[34705, 996, 320, 10, 92, "Input"],
Cell[35028, 1008, 676, 21, 92, "Input"],
Cell[35707, 1031, 226, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[35958, 1040, 251, 5, 52, "Input"],
Cell[36212, 1047, 4921, 94, 133, "Output"]
}, Open  ]],
Cell[41148, 1144, 682, 12, 201, "Text"],
Cell[41833, 1158, 1199, 27, 192, "Input"],
Cell[43035, 1187, 204, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[43264, 1195, 97, 2, 31, "Input"],
Cell[43364, 1199, 80, 1, 31, "Output"]
}, Open  ]],
Cell[43459, 1203, 226, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[43710, 1213, 139, 3, 31, "Input"],
Cell[43852, 1218, 5794, 78, 392, "Output"]
}, Open  ]],
Cell[49661, 1299, 592, 12, 125, "Text"],
Cell[50256, 1313, 1026, 25, 172, "Input"],
Cell[CellGroupData[{
Cell[51307, 1342, 321, 9, 52, "Input"],
Cell[51631, 1353, 3257, 44, 392, "Output"]
}, Open  ]],
Cell[54903, 1400, 350, 10, 49, "Text"],
Cell[CellGroupData[{
Cell[55278, 1414, 158, 6, 60, "Subsection"],
Cell[CellGroupData[{
Cell[55461, 1424, 148, 4, 47, "Input"],
Cell[55612, 1430, 72, 1, 31, "Output"]
}, Open  ]],
Cell[55699, 1434, 283, 8, 47, "Input"],
Cell[55985, 1444, 1731, 49, 248, "Input"],
Cell[CellGroupData[{
Cell[57741, 1497, 378, 11, 68, "Input"],
Cell[58122, 1510, 125, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58284, 1518, 378, 11, 68, "Input"],
Cell[58665, 1531, 150, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58852, 1539, 378, 11, 68, "Input"],
Cell[59233, 1552, 170, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59440, 1561, 415, 12, 68, "Input"],
Cell[59858, 1575, 181, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60076, 1585, 185, 5, 47, "Input"],
Cell[60264, 1592, 95, 1, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60408, 1599, 159, 6, 60, "Subsection"],
Cell[60570, 1607, 1337, 36, 228, "Input"],
Cell[61910, 1645, 258, 7, 47, "Input"],
Cell[62171, 1654, 1794, 50, 248, "Input"],
Cell[CellGroupData[{
Cell[63990, 1708, 379, 11, 68, "Input"],
Cell[64372, 1721, 135, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64544, 1729, 416, 12, 68, "Input"],
Cell[64963, 1743, 203, 5, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65203, 1753, 846, 24, 148, "Input"],
Cell[66052, 1779, 93, 1, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[66194, 1786, 107, 2, 59, "Subsection"],
Cell[66304, 1790, 945, 27, 168, "Input"],
Cell[67252, 1819, 344, 10, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67633, 1834, 114, 2, 59, "Subsection"],
Cell[CellGroupData[{
Cell[67772, 1840, 477, 10, 68, "Input"],
Cell[68252, 1852, 5512, 103, 131, "Output"]
}, Open  ]],
Cell[73779, 1958, 301, 9, 47, "Input"],
Cell[CellGroupData[{
Cell[74105, 1971, 358, 11, 108, "Input"],
Cell[74466, 1984, 321, 7, 52, "Output"]
}, Open  ]],
Cell[74802, 1994, 740, 23, 128, "Input"],
Cell[75545, 2019, 359, 9, 68, "Input"],
Cell[CellGroupData[{
Cell[75929, 2032, 238, 5, 47, "Input"],
Cell[76170, 2039, 10376, 184, 164, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

